// 导出页面为PDF格式
import html2Canvas from 'html2canvas'
import JsPDF from 'jspdf'
import "./lm-normal.js";
export default{
    install (Vue, options) {
        const addWatermark = (pdf, watermarkText) => {
            // 获取PDF页数，给PDF每一页添加水印
            var totalPages = pdf.internal.getNumberOfPages();
            for (let i = 1; i <= totalPages; i++) {
                pdf.setPage(i);
                addWatermarkFill(pdf, watermarkText);
            }
            return pdf;
        }
         
        const addWatermarkFill = (pdf, watermarkText) => {
            let pdfW = pdf.internal.pageSize.getWidth();
            let pdfH = pdf.internal.pageSize.getHeight();
            // 250是可以根据水印的大小调整的 可以优化为单水印的长和宽
            let xCount = pdfW / 250; 
            let yCount = pdfH / 250;
            // 下面的for循环的作用是在页面上铺满水印
            for (let y = 0; y < yCount; y++) {
                let yLocation = y * 250;
                for (let x = 0; x < xCount; x++) {
                    let xLocation = x * 250;
                    pdf.saveGraphicsState() // 保存图形状态
                    pdf.setFontSize(40);       // 设置水印字体大小
                    pdf.setTextColor(200);    // 设置水印颜色
                    pdf.setGState(pdf.GState({ opacity: 0.3 })) // 设置透明度为0.3
                    // 这里的lm是字体包 解决jsPDF 无法使用中文问题
                    pdf.setFont('lm');
                    pdf.text(watermarkText, xLocation, yLocation, { align: 'center', angle: -45}, 45);
                    pdf.restoreGraphicsState()
                }
            }
            return pdf;
        }
        Vue.prototype.getPdf = (dom,title) =>{
            html2Canvas(document.querySelector(dom), {
                allowTaint: true,
                useCORS: true,
            }).then((canvas) =>{
                let contentWidth = canvas.width //html页面的实际宽度
                let contentHeight = canvas.height //html页面的实际高度
                let pageHeight = contentWidth / 592.28 * 841.89 // 分页的高度
                let leftHeight = contentHeight
                let position = 0
                //a4纸的尺寸[595.28,841.89]，html页面生成的canvas在pdf中图片的宽高
                let imgWidth = 595.28  // A4 宽度
                let imgHeight = 592.28 / contentWidth * contentHeight // A4总高度
                let pageData = canvas.toDataURL('image/jpeg', 1.0)
                let PDF = new JsPDF('', 'pt', 'a4')
                //有两个高度需要区分，一个是html页面的实际高度，和生成pdf的页面高度(841.89)
                //当内容未超过pdf一页显示的范围，无需分页
                if (leftHeight < pageHeight) {
                    /**
                     * 如果想要pdf的分页，与html自己写的每一块都匹配；
                     * 1.则pageHeight的高度要与html每一块的高度相同
                     * 2.addImage的最后一个参数，不要传A4纸高度，要传实际html的高度contentHeight
                     */
                    PDF.addImage(pageData, 'JPEG', 0, 0, imgWidth, imgHeight) // 最后两个参数代表：实际导出pda每页实际内容的宽高；
                    // PDF.addImage(pageData, 'JPEG', 0, 0, imgWidth, contentHeight)
                } else {
                    while (leftHeight > 0) {
                        PDF.addImage(pageData, 'JPEG', 0, position, imgWidth, imgHeight)
                        leftHeight -= pageHeight
                        position -= 841.89
                        if (leftHeight   > 0) {
                            PDF.addPage()
                        }
                    }
                }
                PDF = addWatermark(PDF,'上海面心科技')
                PDF.save(title?title:'导出...' + '.pdf')
            })
        }
    }
}