import axios from 'axios';
import md5 from 'js-md5';
import router from '../router';
axios.defaults.timeout = 120000;

if (process.env.NODE_ENV == 'development') {
    // 测试地址
    // axios.defaults.baseURL = 'http://192.168.137.119:8060'
    // axios.defaults.baseURL = 'http://192.168.188.158:8060'
    axios.defaults.baseURL = sessionStorage.getItem('uploadUrl');
} else {
    // 生产地址
    // axios.defaults.baseURL = 'https://xx.y-open.com/iotweb'

    // axios.defaults.baseURL = window.location.origin + '/dxiotweb'; //正式环境接口
    axios.defaults.baseURL = window.location.origin + '/dxiotweb'; //测试环境接口
}

//http request 拦截器

axios.defaults.headers['Content-Type'] = 'application/json;charset=utf-8';

axios.interceptors.request.use(
    config => {
        config.data = JSON.stringify(config.data);
        return config;
    },
    error => {
        return Promise.reject(err);
    }
);

//http response 拦截器
axios.interceptors.response.use(
    response => {
        if (!/user\/access\/loginIn$/.test(response.request.responseURL) && !/tims\/machine\/api\/entrance$/.test(response.request.responseURL)) {
            if (sessionStorage.getItem('tokey') == null || (response.data && (response.data.msgCode == 'S40' || response.data.msgCode == 'S400'))) {
                sessionStorage.removeItem('menuList');
                sessionStorage.removeItem('userName');
                sessionStorage.removeItem('institutionIdList');
                sessionStorage.removeItem('institutionName');
                sessionStorage.removeItem('marketplace_type');
                sessionStorage.removeItem('phone');
                sessionStorage.removeItem('name');
                sessionStorage.removeItem('userMail');
                sessionStorage.removeItem('jobContent');
                sessionStorage.removeItem('userJob');
                sessionStorage.removeItem('tokey');
                sessionStorage.removeItem('dtstart');
                router.push({ path: window.routeDir + '/pages/login' });
            }
        }
        response.data = changeFtpURL(response.data);
        return response;
    },
    error => {
        return Promise.reject(error);
    }
);

/**
 * 封装get方法
 * @param url
 * @param data
 * @returns {Promise}
 */

export function get(url, params = {}) {
    return new Promise((resolve, reject) => {
        axios.get(url, { params: params }).then(
            response => {
                resolve(response.data);
            },
            err => {
                if (String(err).toLowerCase() == 'error: network error') {
                    this.$message({ type: 'error', message: '网络异常，请稍后重试' });
                    return;
                }
                reject(err);
            }
        );
    }).catch(error => {
        if (String(error).toLowerCase() == 'error: network error') {
            this.$message({ type: 'error', message: '网络异常，请稍后重试' });
            return;
        }
    });
}

/**
 * 封装post请求
 * @param url
 * @param data
 * @returns {Promise}
 */

export function post(url, data = {}) {
    return new Promise((resolve, reject) => {
        axios.post(url, data).then(
            response => {
                resolve(response.data);
            },
            err => {
                if (String(err).toLowerCase() == 'error: network error') {
                    this.$message({ type: 'error', message: '网络异常，请稍后重试' });
                    return;
                }
                reject(err);
            }
        );
    }).catch(error => {
        if (String(error).toLowerCase() == 'error: network error') {
            this.$message({ type: 'error', message: '网络异常，请稍后重试' });
            return;
        }
    });
}

export function postResponseFile(url, data = {}) {
    return new Promise((resolve, reject) => {
        axios.post(url, data, { responseType: 'blob' }).then(
            response => {
                resolve(response.data);
            },
            err => {
                reject(err);
            }
        );
    });
}

/**
 * 封装patch请求
 * @param url
 * @param data
 * @returns {Promise}
 */

export function patch(url, data = {}) {
    return new Promise((resolve, reject) => {
        axios.patch(url, data).then(
            response => {
                resolve(response.data);
            },
            err => {
                reject(err);
            }
        );
    });
}

/**
 * 封装put请求
 * @param url
 * @param data
 * @returns {Promise}
 */

export function put(url, data = {}) {
    return new Promise((resolve, reject) => {
        axios.put(url, data).then(
            response => {
                resolve(response.data);
            },
            err => {
                reject(err);
            }
        );
    });
}

/**
 * 权限接口加密处理
 * @param  {[type]} url  [description]
 * @param  {Object} data [description]
 * @return {[type]}      [description]
 */
export function getItoInterfaceInfo(data = {}) {
    console.log(data,'入参---------------')
    //return new Promise((resolve, reject) => {
    let Base64 = require('js-base64').Base64;
    var md5data = JSON.stringify(data) + 'MXITOTIMSYYYY2019MM04DD22';
    var itodata = JSON.parse(JSON.stringify(data));
    itodata['disgst'] = md5(md5data);
    var basedata = Base64.encode(JSON.stringify(itodata));
    var bta1 = basedata.substring(0, 5);
    var bta2 = basedata.substring(5, basedata.length);
    var bta = bta1 + 'I' + bta2;
    var bd1 = bta.replace(new RegExp('I', 'g'), '&');
    var bd2 = bd1.replace(new RegExp('G', 'g'), 'I');
    var bd3 = bd2.replace(new RegExp('M', 'g'), 'G');
    var bd4 = bd3.replace(new RegExp('J', 'g'), 'M');
    var bd5 = bd4.replace(new RegExp('O', 'g'), 'J');
    var bd6 = bd5.replace(new RegExp('W', 'g'), 'O');
    var bd7 = bd6.replace(new RegExp('N', 'g'), 'W');
    var bd8 = bd7.replace(new RegExp('T', 'g'), 'N');
    return bd8;
    //resolve(bd8);
    //})
}
export function getItoInterfaceInfo2(data = {}) {
    var md5data = JSON.stringify(data) + '_EMM-MDM-api-#*$@-20201123';
    return md5(md5data);
}

if (process.env.NODE_ENV == 'development') {
    window.decode = function(val) {
        let Base64 = require('js-base64').Base64;

        var val = val.substring(0, 5) + val.substring(6, val.length);
        var val = val.replace(new RegExp('N', 'g'), 'T');
        var val = val.replace(new RegExp('W', 'g'), 'N');
        var val = val.replace(new RegExp('O', 'g'), 'W');
        var val = val.replace(new RegExp('J', 'g'), 'O');
        var val = val.replace(new RegExp('M', 'g'), 'J');
        var val = val.replace(new RegExp('G', 'g'), 'M');
        var val = val.replace(new RegExp('I', 'g'), 'G');
        var val = val.replace(new RegExp('&', 'g'), 'I');
        var basedata = Base64.decode(val);

        return basedata;
    };
    window.encode = function(data = {}) {
        //return new Promise((resolve, reject) => {
        let Base64 = require('js-base64').Base64;
        var md5data = JSON.stringify(data) + 'MXITOTIMSYYYY2019MM04DD22';
        var itodata = JSON.parse(JSON.stringify(data));
        itodata['disgst'] = md5(md5data);
        var basedata = Base64.encode(JSON.stringify(itodata));
        var bta1 = basedata.substring(0, 5);
        var bta2 = basedata.substring(5, basedata.length);
        var bta = bta1 + 'I' + bta2;
        var bd1 = bta.replace(new RegExp('I', 'g'), '&');
        var bd2 = bd1.replace(new RegExp('G', 'g'), 'I');
        var bd3 = bd2.replace(new RegExp('M', 'g'), 'G');
        var bd4 = bd3.replace(new RegExp('J', 'g'), 'M');
        var bd5 = bd4.replace(new RegExp('O', 'g'), 'J');
        var bd6 = bd5.replace(new RegExp('W', 'g'), 'O');
        var bd7 = bd6.replace(new RegExp('N', 'g'), 'W');
        var bd8 = bd7.replace(new RegExp('T', 'g'), 'N');
        return bd8;
        //resolve(bd8);
        //})
    };
}
