/**
 * @name formDate
 */
// 格式化时间

export const formDate = (time, formate) => {
    if (!time) {
        time = new Date();
    }
    var times = time;
    var formAte = formate || "yyyy-MM-dd HH:mm:ss";
    var date = {
        y: new Date(times).getFullYear(),
        M: new Date(times).getMonth() + 1,
        d: new Date(times).getDate(),
        h: new Date(times).getHours(),
        m: new Date(times).getMinutes(),
        s: new Date(times).getSeconds()
    };
    for (var key in date) {
        if (date[key] < 10) {
            date[key] = "0" + date[key];
        }
    }
    return formAte
        .replace(/[Yy]{4}/, date.y)
        .replace(/[M]{2}/, date.M)
        .replace(/[Dd]{2}/, date.d)
        .replace(/[Hh]{2}/, date.h)
        .replace(/[m]{2}/, date.m)
        .replace(/[s]{2}/, date.s);
};

// 时间戳转换成日期
// 时间戳转换成YYYY/MM/DD HH:MM:SS(时间戳已经是毫秒级)
// item_date：时间戳 str: 日期展示的分隔符，默认展示'-'
export const formatDate = (item_date, str = "-") => {
    let date = new Date(parseInt(item_date));
    let YY = date.getFullYear() + str;
    let MM = (date.getMonth() + 1 < 10 ? "0" + (date.getMonth() + 1) : date.getMonth() + 1) + str;
    let DD = date.getDate() < 10 ? "0" + date.getDate() : date.getDate();
    let hh = (date.getHours() < 10 ? "0" + date.getHours() : date.getHours()) + ":";
    let mm = (date.getMinutes() < 10 ? "0" + date.getMinutes() : date.getMinutes()) + ":";
    let ss = date.getSeconds() < 10 ? "0" + date.getSeconds() : date.getSeconds();
    return YY + MM + DD + " " + hh + mm + ss;
};

// 时间戳转换成YYYY/MM/DD 不带时分秒(时间戳已经是毫秒级)
// item_date：时间戳 str: 日期展示的分隔符，默认展示'-'
export const formatDay = (item_date, str = "-") => {
    let date = new Date(parseInt(item_date));
    let YY = date.getFullYear() + str;
    let MM = (date.getMonth() + 1 < 10 ? "0" + (date.getMonth() + 1) : date.getMonth() + 1) + str;
    let DD = date.getDate() < 10 ? "0" + date.getDate() : date.getDate();
    let hh = (date.getHours() < 10 ? "0" + date.getHours() : date.getHours()) + ":";
    let mm = (date.getMinutes() < 10 ? "0" + date.getMinutes() : date.getMinutes()) + ":";
    let ss = date.getSeconds() < 10 ? "0" + date.getSeconds() : date.getSeconds();
    return YY + MM + DD;
};

/**
 * @name numberToCurrencyNo
 */
// 千位数分隔符

export const numberToCurrencyNo = value => {
    if (!value) return 0;
    // 获取整数部分
    const intPart = Math.trunc(value);
    // 整数部分处理，增加,
    const intPartFormat = intPart.toString().replace(/(\d)(?=(?:\d{3})+$)/g, "$1,");
    // 预定义小数部分
    let floatPart = "";
    // 将数值截取为小数部分和整数部分
    const valueArray = value.toString().split(".");
    if (valueArray.length === 2) {
        // 有小数部分
        floatPart = valueArray[1].toString(); // 取得小数部分
        return intPartFormat + "." + floatPart;
    }
    return intPartFormat + floatPart;
};

//高德地图经纬度百度转换

export const switchLngLat = (lng, lat) => {
    let p = new Promise( (resolve, reject) => {
        let url = `https://api.map.baidu.com/geoconv/v1/?coords=${lng},${lat}&from=3&to=5&ak=nvbMQN9pTKukllCQKPdPd2fv47A4fF5D` 
        let obj = {}
        vue.$get(url).then(res => {
            obj = res.result[0]
            resolve(obj)
        })
    })
    return p
}

// 获取浏览器名称及其版本号
export const getBrowserName = () => {
    var Sys = {};
    var ua = navigator.userAgent.toLowerCase();
    var s;
    (s = ua.match(/rv:([\d.]+)\) like gecko/)) ? Sys.ie = s[1]:
        (s = ua.match(/msie ([\d\.]+)/)) ? Sys.ie = s[1] :
        (s = ua.match(/edge\/([\d\.]+)/)) ? Sys.edge = s[1] :
        (s = ua.match(/firefox\/([\d\.]+)/)) ? Sys.firefox = s[1] :
        (s = ua.match(/(?:opera|opr).([\d\.]+)/)) ? Sys.opera = s[1] :
        (s = ua.match(/chrome\/([\d\.]+)/)) ? Sys.chrome = s[1] :
        (s = ua.match(/version\/([\d\.]+).*safari/)) ? Sys.safari = s[1] : 0;
    // 根据关系进行判断
    if (Sys.ie) return ('IE' + Sys.ie);
    if (Sys.edge) return ('EDGE' + Sys.edge);
    if (Sys.firefox) return ('Firefox' + Sys.firefox);
    if (Sys.chrome) return ('Chrome' + Sys.chrome);
    if (Sys.opera) return ('Opera' + Sys.opera);
    if (Sys.safari) return ('Safari' + Sys.safari);
    return 'Unkonwn';
}

// js处理数字变成单位为 千、万、千万、亿
export function bigNumberTransform (value) {
    const newValue = ['', '', '']
    let fr = 1000
    let num = 3
    let text1 = ''
    let fm = 1
    while (value / fr >= 1) {
        fr *= 10
        num += 1
        // console.log('数字', value / fr, 'num:', num)
    }
    if (num <= 4) { // 千
        newValue[0] = parseInt(value / 1000) + ''
        newValue[1] = '千'
    } else if (num <= 8) { // 万
        text1 = parseInt(num - 4) / 3 > 1 ? '千万' : '万'
        // tslint:disable-next-line:no-shadowed-variable
        fm = text1 === '万' ? 10000 : 10000000
        if (value % fm === 0) {
            newValue[0] = parseInt(value / fm) + ''
        } else {
            newValue[0] = parseFloat(value / fm).toFixed(2) + ''
        }
        newValue[1] = text1
    } else if (num <= 16) { // 亿
        text1 = (num - 8) / 3 > 1 ? '千亿' : '亿'
        text1 = (num - 8) / 4 > 1 ? '万亿' : text1
        text1 = (num - 8) / 7 > 1 ? '千万亿' : text1
        // tslint:disable-next-line:no-shadowed-variable
        fm = 1
        if (text1 === '亿') {
            fm = 100000000
        } else if (text1 === '千亿') {
            fm = 100000000000
        } else if (text1 === '万亿') {
            fm = 1000000000000
        } else if (text1 === '千万亿') {
            fm = 1000000000000000
        }
        if (value % fm === 0) {
            newValue[0] = parseInt(value / fm) + ''
        } else {
            newValue[0] = parseFloat(value / fm).toFixed(2) + ''
        }
        newValue[1] = text1
    }
    if (value < 1000) {
        newValue[0] = value + ''
        newValue[1] = ''
    }
    return newValue.join('')
}

export function echartGetFontSize(font) {
    let docEl = document.documentElement,
      clientWidth =
        window.innerWidth ||
        document.documentElement.clientWidth ||
        document.body.clientWidth;
    if (!clientWidth) return;
    let fontSize = clientWidth / 1920;
    return font * fontSize;
}